@@ -4,7 +4,7 @@ use strict;
 BEGIN { eval { require warnings; warnings->import } }
 
 our @EXPORT_OK = qw( rename );
-our $VERSION = '1.29_04';
+our $VERSION = '1.29_05';
 
 sub import {
     require Exporter;
@@ -22,7 +22,8 @@ sub rename_files {
     my $sub = $code;
     if ( $options->{unicode_strings} ) {
         require File::Rename::Unicode;
-        $sub = File::Rename::Unicode::code($code);
+        $sub = File::Rename::Unicode::code($code,
+                            $options->{encoding});
     }
     my $errors;
     for (@_) {
@@ -100,9 +101,7 @@ CARP
     unless( ref $code ) {
         if( my $eval = eval <<CODE )
 sub {
-#line 1
 $code
-#line
 }
 CODE
         {
@@ -110,11 +109,9 @@ CODE
         }
         else {
             my $error = $@;
-            $error =~ s/\(eval\s+\d+\)/\(user-supplied code\)/g;
-            $error =~ s/\s+line\s+1\b//g unless $code =~ /\n/;
-            $error =~ s/\"[^#"]*\#line\s+1\n/"/;
-            $error =~ s/\n\#line\n[^#"]*\"/"/;
-            $error =~ s/\s*\z/\n/;
+            $error =~ s/\b(at\s+)\(eval\s+\d+\)\s/$1/g;
+            $error =~ s/(\s+line\s+)(\d+)\b/$1 . ($2-1)/eg;
+            $error =~ s/\.?\s*\z/, in:\n$code\n/;
             die $error;
         }
     }
@@ -243,6 +240,10 @@ Print version number, provided by B<-V>.
 
 Enable unicode_strings feature, provided by B<-u>.
 
+=item B<encoding> 
+
+Encoding for filenames, provided by B<-u>.
+
 =back
 
 =head2 EXPORT
