@@ -5,15 +5,26 @@ use 5.012;
 use strict;
 use warnings;
 
+use Encode qw(encode decode);
+
 our $VERSION = '1.0';
 
 sub code {
     my $code = shift;
+    my $encoding = shift;
     return
         sub {
             use feature 'unicode_strings';
-            utf8::upgrade $_;
+            if ( $encoding ) {
+                $_ = decode($encoding, $_);
+            }
+            else {
+                utf8::upgrade $_;
+            }
             $code->();
+            if ( $encoding ) {
+                $_ = encode($encoding, $_);
+            }
         };
 }
 
@@ -28,7 +39,7 @@ File::Rename::Unicode - Unicode wrapper for user code for File::Rename
 =head1 SYNOPSIS
 
     require File::Rename::Unicode;
-    my $sub = File::Rename::Unicode::code($code);
+    my $sub = File::Rename::Unicode::code($code, $enc);
 
 =head1 DESCRIPTION
 
